/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { PostfachMailListLinkRel } from '@alfa-client/postfach-shared';
import {
  ConvertForDataTestPipe,
  HasLinkPipe,
  StateResource,
  ToEmbeddedResourcesPipe,
  createStateResource,
} from '@alfa-client/tech-shared';
import { getElementFromFixture, getElementFromFixtureByType, getMockComponent } from '@alfa-client/test-utils';
import { ExpansionPanelComponent, SpinnerComponent } from '@alfa-client/ui';
import { VorgangWithEingangResource } from '@alfa-client/vorgang-shared';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { createPostfachMailListResource } from 'libs/postfach-shared/test/postfach';
import { getDataTestIdOf } from 'libs/tech-shared/test/data-test';
import { MockComponent } from 'ng-mocks';
import { createVorgangWithEingangResource } from '../../../../../vorgang-shared/test/vorgang';
import { PostfachMailButtonContainerComponent } from '../../postfach-mail-button-container/postfach-mail-button-container.component';
import { PostfachMailPdfButtonContainerComponent } from '../../postfach-mail-pdf-button-container/postfach-mail-pdf-button-container.component';
import { PostfachMailListMailboxIconComponent } from './mailbox-icon/mailbox-icon.component';
import { PostfachMailListComponent } from './postfach-mail-list.component';
import { PostfachMailComponent } from './postfach-mail/postfach-mail.component';

describe('PostfachMailListComponent', () => {
  let component: PostfachMailListComponent;
  let fixture: ComponentFixture<PostfachMailListComponent>;

  const postfachMailButton: string = getDataTestIdOf('postfach-mail-button-container');
  const noPostfachText: string = getDataTestIdOf('no-postfach-text');

  const vorgangStateResource: StateResource<VorgangWithEingangResource> = createStateResource(createVorgangWithEingangResource());

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [
        PostfachMailListComponent,
        ToEmbeddedResourcesPipe,
        ConvertForDataTestPipe,
        HasLinkPipe,
        MockComponent(ExpansionPanelComponent),
        MockComponent(PostfachMailComponent),
        MockComponent(SpinnerComponent),
        MockComponent(PostfachMailButtonContainerComponent),
        MockComponent(PostfachMailPdfButtonContainerComponent),
        MockComponent(PostfachMailListMailboxIconComponent),
      ],
    }).compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(PostfachMailListComponent);
    component = fixture.componentInstance;
    component.postfachMailListStateResource = createStateResource(createPostfachMailListResource());
    component.vorgangStateResource = vorgangStateResource;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('postfach exists', () => {
    beforeEach(() => {
      component.postfachMailListStateResource = createStateResource(
        createPostfachMailListResource([PostfachMailListLinkRel.SEND_POSTFACH_MAIL]),
      );
      component.vorgangStateResource = createStateResource(createVorgangWithEingangResource());
      fixture.detectChanges();
    });

    it('should show button', () => {
      const button = getElementFromFixture(fixture, postfachMailButton);

      expect(button).toBeInstanceOf(HTMLElement);
    });

    it('should hide text', () => {
      const button = getElementFromFixture(fixture, noPostfachText);

      expect(button).not.toBeInstanceOf(HTMLElement);
    });
  });

  describe('postfach does not exists', () => {
    beforeEach(() => {
      component.postfachMailListStateResource = createStateResource(createPostfachMailListResource());
      fixture.detectChanges();
    });

    it('should hide button', () => {
      const button = getElementFromFixture(fixture, postfachMailButton);

      expect(button).not.toBeInstanceOf(HTMLElement);
    });

    it('should show text', () => {
      const button = getElementFromFixture(fixture, noPostfachText);

      expect(button).toBeInstanceOf(HTMLElement);
    });
  });

  describe('postfachMail component', () => {
    it('should have been called with vorgangStateResource', () => {
      const postfachMailComponent: PostfachMailComponent = getMockComponent(fixture, PostfachMailComponent);

      expect(postfachMailComponent.vorgangStateResource).toBe(vorgangStateResource);
    });
  });

  describe('mailbox icon', () => {
    it('should exist', () => {
      component.vorgangStateResource.resource.hasNewPostfachNachricht = false;

      fixture.detectChanges();

      const mailboxIcon: PostfachMailListMailboxIconComponent = getElementFromFixtureByType(
        fixture,
        PostfachMailListMailboxIconComponent,
      );
      expect(mailboxIcon.hasNewPostfachNachricht).toEqual(false);
    });
  });
});
