import { PostfachMailListLinkRel, PostfachMailListResource, PostfachService } from '@alfa-client/postfach-shared';
import { HasLinkPipe } from '@alfa-client/tech-shared';
import {
  dispatchEventFromFixture,
  existsAsHtmlElement,
  mock,
  Mock,
  MockEvent,
  notExistsAsHtmlElement,
} from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { ButtonComponent, MailUnreadIconComponent } from '@ods/system';
import { MockComponent } from 'ng-mocks';
import { createPostfachMailListResource } from '../../../../../../postfach-shared/test/postfach';
import { getDataTestIdOf } from '../../../../../../tech-shared/test/data-test';
import { MailUnreadButtonLinkContainerComponent } from './mail-unread-button-link-container.component';

describe('MailUnreadButtonLinkContainerComponent', () => {
  let component: MailUnreadButtonLinkContainerComponent;
  let fixture: ComponentFixture<MailUnreadButtonLinkContainerComponent>;

  let postfachService: Mock<PostfachService>;

  const postfachMailListResource: PostfachMailListResource = createPostfachMailListResource([
    PostfachMailListLinkRel.SET_HAS_NEW_POSTFACH_NACHRICHT,
  ]);

  const button: string = getDataTestIdOf('mail-unread-button-link-host');
  const iconButton: string = getDataTestIdOf('mail-unread-icon-button-link-host');

  beforeEach(async () => {
    postfachService = mock(PostfachService);

    await TestBed.configureTestingModule({
      imports: [MailUnreadButtonLinkContainerComponent, HasLinkPipe],
      declarations: [MockComponent(ButtonComponent), MockComponent(MailUnreadIconComponent)],
      providers: [
        {
          provide: PostfachService,
          useValue: postfachService,
        },
      ],
    }).compileComponents();

    fixture = TestBed.createComponent(MailUnreadButtonLinkContainerComponent);
    component = fixture.componentInstance;
    component.postfachMailListResource = postfachMailListResource;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('component', () => {
    describe('mark mail as unread', () => {
      it('should call set postfach nachrichten as unread', () => {
        component.markMailAsUnread();

        expect(postfachService.setPostfachNachrichtListAsUnread).toHaveBeenCalled();
      });
    });
  });

  describe('template', () => {
    it('no button should exist', () => {});

    describe('icon button', () => {
      it('should exist', () => {
        component.showAsIconButton = true;

        fixture.detectChanges();

        existsAsHtmlElement(fixture, iconButton);
      });

      it('should not exist if link does not exist', () => {
        component.showAsIconButton = true;
        component.postfachMailListResource = createPostfachMailListResource();

        fixture.detectChanges();

        notExistsAsHtmlElement(fixture, iconButton);
      });

      it('should not exist if not shown as icon button', () => {
        component.showAsIconButton = false;

        fixture.detectChanges();

        notExistsAsHtmlElement(fixture, iconButton);
      });

      it('should call markMailAsUnread on click', () => {
        component.showAsIconButton = true;
        component.markMailAsUnread = jest.fn();

        fixture.detectChanges();
        dispatchEventFromFixture(fixture, iconButton, MockEvent.CLICK);

        expect(component.markMailAsUnread).toHaveBeenCalled();
      });
    });
  });

  describe('button', () => {
    it('should exist', () => {
      component.showAsIconButton = false;

      fixture.detectChanges();

      existsAsHtmlElement(fixture, button);
    });

    it('should not exist if link does not exist', () => {
      component.showAsIconButton = false;
      component.postfachMailListResource = createPostfachMailListResource();

      fixture.detectChanges();

      notExistsAsHtmlElement(fixture, button);
    });

    it('should not exist if shown as icon button', () => {
      component.showAsIconButton = true;

      fixture.detectChanges();

      notExistsAsHtmlElement(fixture, button);
    });

    it('should call markMailAsUnread on click', () => {
      component.showAsIconButton = false;
      component.markMailAsUnread = jest.fn();

      fixture.detectChanges();
      dispatchEventFromFixture(fixture, button, MockEvent.CLICK);

      expect(component.markMailAsUnread).toHaveBeenCalled();
    });
  });
});
